//---------------------------------------------------------------------------
#include <vcl.h>
#pragma hdrstop

#include "caView.h"

//---------------------------------------------------------------------------

#pragma package(smart_init)

//---------------------------------------------------------------------------
__fastcall TView::TView()
{
   m_nPoint = -1;
   m_nImgHeight = 0;
   m_nImgWidth = 0;
   m_fImgRatio = 0.0;
   m_zAppDir = ExtractFilePath(Application->ExeName);
   m_zScanDirectory = m_zAppDir;
   m_bRepeat = false;
   m_ScanFilter = new TScanFilter();
}
//---------------------------------------------------------------------------
__fastcall TView::~TView()
{
   SaveFilesToFile();
   delete m_ScanFilter; m_ScanFilter = NULL;
}
//---------------------------------------------------------------------------
//---------------------------------------------------------------------------
int TView::getPoint()
{
   return m_nPoint;
}
//---------------------------------------------------------------------------
void TView::setPoint(int Point)
{
   m_nPoint = Point;
   if (!CheckPoint())
   {
      if (Count>0)
         m_nPoint = 0;
      else
         m_nPoint = -1;
   }
}
//---------------------------------------------------------------------------
bool TView::CheckPoint()
{
   return (m_nPoint>=0 && m_nPoint<Count);
}
//---------------------------------------------------------------------------
bool TView::Previous()
{
   bool bIn = true;
   if (Count<=0) return false;
   m_nPoint--;
   if (!CheckPoint())
   {
      if (m_bRepeat)
         m_nPoint = Count-1;
      else
      {
         m_nPoint =0;
         bIn = false;
      }
   }
   return bIn;
}
//---------------------------------------------------------------------------
bool TView::Next()
{
   bool bIn = true;
   if (Count<=0) return false;
   m_nPoint++;
   if (!CheckPoint())
   {
      if (m_bRepeat)
         m_nPoint =0;
      else
      {
         m_nPoint = Count-1;
         bIn = false;
      }
   }
   return bIn;
}
//---------------------------------------------------------------------------
bool TView::getRepeat()
{
   return m_bRepeat;
}
//---------------------------------------------------------------------------
void TView::setRepeat(bool Repeat)
{
   m_bRepeat = Repeat;
}
//---------------------------------------------------------------------------
AnsiString TView::getScanDirectory()
{
   return m_zScanDirectory;
}
//---------------------------------------------------------------------------
void TView::setScanDirectory(AnsiString ScanDirectory)
{
   m_zScanDirectory = ScanDirectory;
}
//---------------------------------------------------------------------------
TScanFilter *TView::getScanFilter()
{
   return m_ScanFilter;
}
//---------------------------------------------------------------------------
void TView::setScanFilter(TScanFilter *ScanFilter)
{
   m_ScanFilter = ScanFilter;
}
//---------------------------------------------------------------------------
void TView::LoadFilesFromFile()
{
   if (FileExists(m_zAppDir+"ScanFiles.ini"))
      LoadFromFile(m_zAppDir+"ScanFiles.ini");
}
//---------------------------------------------------------------------------
void TView::SaveFilesToFile()
{
   SaveToFile(m_zAppDir+"ScanFiles.ini");
}
//---------------------------------------------------------------------------
void TView::ScanDirectoryFiles()
{
   Clear();
   ScanDirectoryFiles(m_zScanDirectory.c_str());
   if (!CheckPoint()) m_nPoint = 0;
}
//---------------------------------------------------------------------------
void TView::ScanDirectoryFiles(char *dirname)
{
   DIR *dir;
   struct dirent *ent;
   AnsiString tmp, ext;
   int attrib;

   if ((dir = opendir(dirname)) == NULL)
      return;

   while ((ent = readdir(dir)) != NULL)
   {
      tmp = (AnsiString)dirname +"\\"+(AnsiString)ent->d_name;

      attrib = _rtl_chmod(tmp.c_str(), 0);

      if ( (AnsiString)ent->d_name != "." && (AnsiString)ent->d_name != "..")
      {
         if (attrib & FA_DIREC) //O_ؿ
         {
            ScanDirectoryFiles(tmp.c_str());
         }
         else  //O_View Filter]w
         {
            ext = ExtractFileExt(tmp).LowerCase();

            if (m_ScanFilter->getJPG() && ext == ".jpg" )
               Add(tmp);
            if (m_ScanFilter->getBMP() && ext == ".bmp" )
               Add(tmp);
         }
      }
   }

   if (closedir(dir) != 0)
      perror("Unable to close directory");
}
//---------------------------------------------------------------------------
AnsiString TView::getFilePath()
{
   if (!CheckPoint()) return "";
   return ExtractFilePath(Strings[m_nPoint]);
}
//---------------------------------------------------------------------------
AnsiString TView::getPicName()
{
   if (!CheckPoint()) return "";
   return ExtractFileName(Strings[m_nPoint]);
}
//---------------------------------------------------------------------------
AnsiString TView::getDocName()
{
   AnsiString z = getPicName();
   if (z!="")
      return ChangeFileExt(z, ".doc");
   else
      return z;
}
//---------------------------------------------------------------------------
int TView::getImgHeight()
{
   return m_nImgHeight;
}
//---------------------------------------------------------------------------
void TView::setImgHeight(int ImgHeight)
{
   m_nImgHeight = ImgHeight;
}
//---------------------------------------------------------------------------
int TView::getImgWidth()
{
   return m_nImgWidth;
}
//---------------------------------------------------------------------------
void TView::setImgWidth(int ImgWidth)
{
   m_nImgWidth = ImgWidth;
}
//---------------------------------------------------------------------------
float TView::getImgRatio(int RealHeight, int RealWidth)
{
   return (double)((double)RealHeight/(double)m_nImgHeight);
}
//---------------------------------------------------------------------------
void TView::setImgRatio(float ImgRatio)
{
   m_fImgRatio = ImgRatio;
}
//---------------------------------------------------------------------------
